﻿
Public Class Form1

    'Globals
    Dim Connection As Integer = LGLCD_INVALID_CONNECTION
    Dim Device As Integer = LGLCD_INVALID_DEVICE
    Dim LCD As Bitmap
    Dim LCDType As Long = 0


    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        'free up bitmap.  As I'm not creating new bitmaps every frame, I can wait until
        'I close the form to dispose of it.
        LCD.Dispose()

        'Disconnect and DeInitialize LCD Library
        LcdClose(Device)
        LcdDisconnect(Connection)
        LcdDeInit()
    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'Initialize LCD Library
        LcdInit()
        'Make a connection
        Connection = LcdConnectEx("VB NET Test App", 0, 0)

        'Try to connect to a color device first, then a monochrome device.
        'Use this style even if your program will only operate in monochrome.
        'You can send LCD_DEVICE_BW format images to a color device.
        Device = LcdOpenByType(Connection, LGLCD_DEVICE_QVGA)
        If Device = LGLCD_INVALID_DEVICE Then
            Device = LcdOpenByType(Connection, LGLCD_DEVICE_BW)
            If Device <> LGLCD_INVALID_DEVICE Then
                LCDType = LGLCD_DEVICE_BW
            End If
        Else
            LCDType = LGLCD_DEVICE_QVGA
        End If

        If LCDType = LGLCD_DEVICE_BW Then
            'Creates a new bitmap for output.
            LCD = New Bitmap(160, 43)

            Using g = Graphics.FromImage(LCD)
                g.Clear(Color.White)
            End Using

            'Send bitmap to LCD as monochrome
            LcdUpdateBitmap(Device, LCD.GetHbitmap, LGLCD_DEVICE_BW)
            'Bring display to the front of the device.  Only works after you've first sent a bitmap.
            LcdSetAsLCDForegroundApp(Device, LCD_FORE_YES)

            'Compeltely unnecessary.
            PictureBox1.Width = 160
            PictureBox1.Height = 43
            PictureBox1.Image = LCD


        Else
            'Creates a new bitmap for output
            LCD = New Bitmap(320, 240)

            Using g = Graphics.FromImage(LCD)
                g.Clear(Color.White)
            End Using

            'Send bitmap to LCD as color
            LcdUpdateBitmap(Device, LCD.GetHbitmap, LGLCD_DEVICE_QVGA)
            'Bring display to the front of the device.  Only works after you've first sent a bitmap.
            LcdSetAsLCDForegroundApp(Device, LCD_FORE_YES)

            'Compeltely unnecessary.
            PictureBox1.Width = 320
            PictureBox1.Height = 240
            PictureBox1.Image = LCD

        End If

        If LCDType > 0 Then
            'Enable timer for LCD update routine
            'The lowest this interval should go is around 34ms.
            'Typical usage would be 100ms or 10 frames per second.
            Timer1.Interval = 40
            Timer1.Enabled = True
        End If




    End Sub



    'One method of reading the buttons is to poll the global variable in a timer loop.
    'There are probably better ways of doing this, however.
    Private Sub Timer1_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Timer1.Tick
        Static cnt As Integer
        Static direction As Boolean
        Dim LCDButtons As Long
        Dim sfont As Font


        Using g = Graphics.FromImage(LCD)
            g.Clear(Color.White)

            g.TextRenderingHint = Drawing.Text.TextRenderingHint.AntiAliasGridFit

            If LCDType = LGLCD_DEVICE_BW Then
                sfont = New Font(FontFamily.GenericSansSerif, 8, System.Drawing.FontStyle.Regular)
            Else
                sfont = New Font(FontFamily.GenericSansSerif, 14, System.Drawing.FontStyle.Regular)
            End If

            LCDButtons = LcdReadSoftButtons(Device)

            'AND the button variable with the constant for the button you wish to check.
            If (LCDButtons And LGLCD_BUTTON_1) = LGLCD_BUTTON_1 Then
                drawTextCircle(g, 15, 25, 6, "1", sfont, Brushes.Black)
            End If
            If (LCDButtons And LGLCD_BUTTON_2) = LGLCD_BUTTON_2 Then
                drawTextCircle(g, 40, 25, 6, "2", sfont, Brushes.Black)
            End If
            If (LCDButtons And LGLCD_BUTTON_3) = LGLCD_BUTTON_3 Then
                drawTextCircle(g, 80, 25, 6, "3", sfont, Brushes.Black)
            End If
            If (LCDButtons And LGLCD_BUTTON_4) = LGLCD_BUTTON_4 Then
                drawTextCircle(g, 115, 25, 6, "4", sfont, Brushes.Black)
            End If

            'G-19 buttons only show up if you use LcdConnectEx instead of LcdConnect
            If (LCDButtons And LGLCD_BUTTON_LEFT) = LGLCD_BUTTON_LEFT Then
                drawTextCircle(g, 100, 120, 15, "L", sfont, Brushes.Black)
            End If
            If (LCDButtons And LGLCD_BUTTON_RIGHT) = LGLCD_BUTTON_RIGHT Then
                drawTextCircle(g, 220, 120, 15, "R", sfont, Brushes.Black)
            End If
            If (LCDButtons And LGLCD_BUTTON_UP) = LGLCD_BUTTON_UP Then
                drawTextCircle(g, 160, 60, 15, "U", sfont, Brushes.Black)
            End If
            If (LCDButtons And LGLCD_BUTTON_DOWN) = LGLCD_BUTTON_DOWN Then
                drawTextCircle(g, 160, 180, 15, "D", sfont, Brushes.Black)
            End If

            If (LCDButtons And LGLCD_BUTTON_MENU) = LGLCD_BUTTON_MENU Then
                drawTextCircle(g, 100, 180, 15, "M", sfont, Brushes.Blue)
            End If
            If (LCDButtons And LGLCD_BUTTON_CANCEL) = LGLCD_BUTTON_CANCEL Then
                drawTextCircle(g, 220, 180, 15, "<=", sfont, Brushes.Red)
            End If
            If (LCDButtons And LGLCD_BUTTON_OK) = LGLCD_BUTTON_OK Then
                drawTextCircle(g, 160, 120, 15, "OK", sfont, Brushes.DarkGreen)
            End If

            'Silly routine to create moving bar.
            If Not direction Then
                cnt = cnt + 1
                If cnt > 25 Then
                    direction = Not direction
                    cnt = 25
                End If
            Else
                cnt = cnt - 1
                If cnt < 1 Then
                    direction = Not direction
                    cnt = 1
                End If
            End If


            g.DrawString("This is a test", sfont, Brushes.Black, 0, 0)
            g.DrawString(StrDup(cnt, "="), sfont, Brushes.Black, 0, 30)

            'Dispose the font.
            sfont.Dispose()
        End Using

        'Send the bitmap to the LCD.
        If LCDType = LGLCD_DEVICE_BW Then
            LcdUpdateBitmap(Device, LCD.GetHbitmap, LGLCD_DEVICE_BW)
        Else
            LcdUpdateBitmap(Device, LCD.GetHbitmap, LGLCD_DEVICE_QVGA)
        End If

        'Updates the picturebox on the form.  This would normally be left out.
        PictureBox1.Image = LCD



    End Sub

    'Simple subroutine to draw text in a circle.
    Public Sub drawTextCircle(ByVal g As Graphics, ByVal x As Integer, ByVal y As Integer, ByVal r As Integer, ByVal txt As String, ByVal fnt As Font, ByVal b As Brush)

        Using p As New Pen(b)
            g.DrawEllipse(p, x - r, y - r, r * 2, r * 2)
            Dim txtSize As SizeF = g.MeasureString(txt, fnt)
            g.DrawString(txt, fnt, b, x - txtSize.Width / 2, y - txtSize.Height / 2 + 1)
        End Using

    End Sub


End Class
