﻿

Module Module1
    'Constants
    Public Const ERROR_SUCCESS As Long = 0
    Public Const LCD_FORE_YES As Long = 1
    Public Const LCD_FORE_NO As Long = 0
    Public Const LGLCD_DEVICE_BW As Long = 1
    Public Const LGLCD_DEVICE_QVGA As Long = 2
    Public Const LGLCD_INVALID_DEVICE As Long = -1
    Public Const LGLCD_INVALID_CONNECTION As Long = -1

    'G-15 Button Constants
    Public Const LGLCD_BUTTON_1 As UInt32 = 1
    Public Const LGLCD_BUTTON_2 As UInt32 = 2
    Public Const LGLCD_BUTTON_3 As UInt32 = 4
    Public Const LGLCD_BUTTON_4 As UInt32 = 8

    'G-19 Button Constants
    Public Const LGLCD_BUTTON_LEFT As UInt32 = &H100
    Public Const LGLCD_BUTTON_RIGHT As UInt32 = &H200
    Public Const LGLCD_BUTTON_OK As UInt32 = &H400
    Public Const LGLCD_BUTTON_CANCEL As UInt32 = &H800
    Public Const LGLCD_BUTTON_UP As UInt32 = &H1000
    Public Const LGLCD_BUTTON_DOWN As UInt32 = &H2000
    Public Const LGLCD_BUTTON_MENU As UInt32 = &H4000

    ''' <summary>
    ''' Initialize LCD Library. 
    ''' </summary>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Must be paired with LcdDeInit.  Put LcdInit in your Form_Load
    ''' or main and LcdDeInit in your exit function (ie. Form_Closing).</remarks>
    Public Declare Function LcdInit Lib "DMcLgLCD.dll" () As UInt32
    ''' <summary>
    ''' Deinitialize LCD Library.  
    ''' </summary>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Put LcdDeInit in your exit function (ie. Form_Closing).</remarks>
    Public Declare Function LcdDeInit Lib "DMcLgLCD.dll" () As UInt32

    ''' <summary>
    ''' Makes a connection to the LCD Library.  Use connection to open a device.
    ''' </summary>
    ''' <param name="appFriendlyName">The name that appears in the Logitech LCD Manager.</param>
    ''' <param name="isPersistent">Not currently used.  Always acts as persistent.</param>
    ''' <param name="isAutostartable">Sets your program to be startable by the Logitech LCD Manager when Windows starts up.  Use 0 for most types of applications.</param>
    ''' <returns>Connection on success.  LGLCD_INVALID_CONNECTION on failure.</returns>
    ''' <remarks>Use only after LcdInit.  Multiple connections are allowed.</remarks>
    Public Declare Function LcdConnect Lib "DMcLgLCD.dll" Alias "LcdConnectA" (ByVal appFriendlyName As String, ByVal isPersistent As Integer, ByVal isAutostartable As Integer) As Integer
    ''' <summary>
    ''' Makes a connection to the LCD Library.  Use connection to open a device.
    ''' </summary>
    ''' <param name="appFriendlyName">The name that appears in the Logitech LCD Manager.</param>
    ''' <param name="isPersistent">Not currently used.  Always acts as persistent.</param>
    ''' <param name="isAutostartable">Sets your program to be startable by the Logitech LCD Manager when Windows starts up.  Use 0 for most types of applications.</param>
    ''' <returns>Connection on success.  LGLCD_INVALID_CONNECTION on failure.</returns>
    ''' <remarks>Use only after LcdInit.  Multiple connections are allowed.  Use LcdConnectExA if you want to access G-19 extended buttons.</remarks>
    Public Declare Function LcdConnectEx Lib "DMcLgLCD.dll" Alias "LcdConnectExA" (ByVal appFriendlyName As String, ByVal isPersistent As Integer, ByVal isAutostartable As Integer) As Integer
    ''' <summary>
    ''' Disconnects from the LCD Library. 
    ''' </summary>
    ''' <param name="connection">Connection that you wish to close.</param>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Each LcdConnect requires it's own LcdDisconnect.  Issue before LcdDeInit.</remarks>
    Public Declare Function LcdDisconnect Lib "DMcLgLCD.dll" (ByVal connection As Integer) As UInt32

    ''' <summary>
    ''' Opens an LCD device for writing.
    ''' </summary>
    ''' <param name="connection">Connection parameter received from an LcdConnect or LcdConnectEx.</param>
    ''' <param name="deviceType">Type of device you want to open.  LGLCD_DEVICE_BW or LGLCD_DEVICE_QVGA.</param>
    ''' <returns>Device number if successful, LGLCD_INVALID_DEVICE otherwise.</returns>
    ''' <remarks>Only one device can be open per connection.</remarks>
    Public Declare Function LcdOpenByType Lib "DMcLgLCD.dll" (ByVal connection As Integer, ByVal deviceType As Integer) As Integer
    ''' <summary>
    ''' Close an LCD device.
    ''' </summary>
    ''' <param name="device">Device number to close.</param>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Issue before LcdDisconnect.</remarks>
    Public Declare Function LcdClose Lib "DMcLgLCD.dll" (ByVal device As Integer) As UInt32

    ''' <summary>
    ''' Updates LCD device with an HBITMAP.
    ''' </summary>
    ''' <param name="device">Device number received from LcdOpenByType.</param>
    ''' <param name="HBITMAP">HBITMAP to display.</param>
    ''' <param name="format">Image format to send. LGLCD_DEVICE_BW or LGLCD_DEVICE_QVGA.</param>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>You can send LGLCD_DEVICE_BW image to both monochrome and color devices.  If you send a
    ''' LGLCD_DEVICE_QVGA image to a monochrome device, nothing with display.  If you send a LGLCD_DEVICE_QVGA
    ''' image to a color device, it will no longer accept LGLCD_DEVICE_BW type images.
    ''' An image too large for the display will be truncated.  One too small will appear in the upper left.</remarks>
    ''' The hBitmap object passed to LcdUpdateBitmap will be deleted by the DLL.  If you need to use it
    ''' elsewhere, be sure to send a copy of it instead.
    ''' <example>
    ''' Using Bitmap LCD As new Bitmap (160, 43)
    '''   Using g = Graphics.FromImage(LCD)
    '''     g.Clear(Color.White)
    '''   End Using
    '''   LcdUpdateBitmap (device, LCD.GetHbitmap, LGLCD_DEVICE_BW)
    ''' End Using
    ''' </example>
    Public Declare Function LcdUpdateBitmap Lib "DMcLgLCD.dll" (ByVal device As Integer, ByVal HBITMAP As IntPtr, ByVal format As Integer) As UInt32

    ''' <summary>
    ''' Brings the device to the forground on the LCD.
    ''' </summary>
    ''' <param name="device">Device received from LcdOpenByType.</param>
    ''' <param name="foregroundYesNoFlag">Either LCD_FORE_YES or LCD_FORE_NO.</param>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Does nothing until after the first LcdUpdateBitmap has been sent.</remarks>
    Public Declare Function LcdSetAsLCDForegroundApp Lib "DMcLgLCD.dll" (ByVal device As Integer, ByVal foregroundYesNoFlag As Integer) As UInt32

    ''' <summary>
    ''' Reads the status of the soft buttons at the time the function is called.
    ''' </summary>
    ''' <param name="device">Device received from LcdOpenByType.</param>
    ''' <returns>OR'd button status.  And with button mask to read status of individual keys.</returns>
    ''' <remarks>Use this function instead of the LcdSetButtonCallback.  This method is more stable.</remarks>
    ''' <example>
    ''' Dim button as UInt32 
    ''' buttons = LcdReadSoftButtons(device)
    ''' If (buttons And LGLCD_BUTTON_1) = LGLCD_BUTTON_1 Then
    ''' </example>
    Public Declare Function LcdReadSoftButtons Lib "DMcLgLCD.dll" (ByVal device As Integer) As UInt32


    ''' <summary>
    ''' Prototype for the config callback function.
    ''' </summary>
    ''' <param name="connection">Connection that is issuing the callback.  Compare with connection from LcdConnect/LcdConnectEx
    ''' if you have more than one connection to the library to determine which configuration to open.</param>
    ''' <remarks>This Sub is called when the user clicks the config button in Logitech's LCD Manager</remarks>
    Public Delegate Sub cfgCallback(ByVal connection As Integer)

    ''' <summary>
    ''' Sets the configuration callback function.
    ''' </summary>
    ''' <param name="configCallback">Name of your callback function.</param>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Use any time after LcdConnect or LcdConnectEx.</remarks>
    Public Declare Function LcdSetConfigCallback Lib "DMcLgLCD.dll" (ByVal configCallback As cfgCallback) As UInt32

    ''' <summary>
    ''' Prototype for button callback routine.  Used in LcdSetButtonCallback
    ''' </summary>
    ''' <param name="deviceType">Returns LGLCD_DEVICE_BW or LGLCD_DEVICE_QVGA.  Useful to determine if device has 4 horizontal buttons (BW) or a dpad arrangement (QVGA)</param>
    ''' <param name="dwButtons">ORed value of all pressed buttons.</param>
    ''' <remarks>Create a separate Public Sub btnCallback(ByVal deviceType As Integer, ByVal dwButtons As Integer)
    ''' to handle the buttons.</remarks>
    Public Delegate Sub btnCallback(ByVal deviceType As Integer, ByVal dwButtons As Integer)

    ''' <summary>
    ''' Assignes a Sub to receive button info.  Do not use this function unless you need to get button info.
    ''' </summary>
    ''' <param name="softkeyCallback">AddressOf btnCallback for button callback</param>
    ''' <returns>ERROR_SUCCESS on success, standard Windows error otherwise.</returns>
    ''' <remarks>Use LcdReadSoftButtons instead.  This function isn't very stable.
    ''' The callback function should complete very quickly and should not call LcdUpdateBitmap.</remarks>
    Public Declare Function LcdSetButtonCallback Lib "DMcLgLCD.dll" (ByVal softkeyCallback As btnCallback) As UInt32

End Module
